#
# spec file for package xauth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xauth
Version:        1.1.3
Release:        1.1
Summary:        Utility to edit and display the X authorization information
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Patch1:         xauth-tolerant-hostname-changes.diff
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmuu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
# Name of subpackage when this was part of the xorg-x11 package up to version 7.6
Provides:       xorg-x11-xauth = 7.6
Obsoletes:      xorg-x11-xauth <= 7.6

%description
The xauth program is used to edit and display the authorization
information used in connecting to the X server.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xauth
%{_mandir}/man1/xauth.1%{?ext_man}

%changelog
* Mon Mar  4 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.3
  * config: Add missing AC_CONFIG_SRCDIR
  * Variable scope reductions, as suggested by cppcheck
  * Remove unnecessary casts from malloc() calls
  * Handle -Wempty-body warning for WRITES() macro
  * configure: Use AC_SYS_LARGEFILE to enable large file support
  * configure: raise minimum autoconf requirement to 2.70
  * unifdef hpux
  * unifdef Lynx
- adjusted xauth-tolerant-hostname-changes.diff
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Wed Apr 20 2022 Stefan Dirsch <sndirsch@suse.com>
- update to version 1.1.2
  * tests: make tests work in out-of-tree builds
  * tests: Fix failure to make distcheck
  * tests: report failure if stderr has unexpected output
  * configure.ac: fail build if xtrans is not found
  * gitlab CI: add a basic build test
  * Build xz tarballs instead of bzip2
  * Fix off-by-one in quote-stripping routines
  * gitlab CI: stop requiring Signed-off-by in commits
  * Improve portability
  * Removed build requirement "cmdtest".
  * Fix warning -Wstringop-truncation for strncpy by using memcpy instead
  * Expand checks of socket file with S_ISSOCK
* Mon Nov 29 2021 Stefan Dirsch <sndirsch@suse.com>
- update to version 1.1.1
  * This is a minor bugfix release, including fixes for reported
    crashes.
* Mon Mar 15 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Fri Jul 12 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1
  * This release fixes a race condition where an existing
    authority file would be unlinked (possibly causing other
    clients to fail to connect), and fixes sorting and merging
    of authority file entries.
* Wed Feb  1 2017 sndirsch@suse.com
- Update to version 1.0.10
  * include POSIX-standard limits.h for PATH_MAX instead of sys/syslimits.h
  * autogen.sh: Honor NOCONFIGURE=1
  * Clarified RELEASING in README
  * Fix for xauth failing on ENOSPC (= disk full)
  * autogen.sh: use quoted string variables
  * Update DISPLAY parsing to work with new launchd paths in Yosemite
  * Fix !HAVE_STRLCPY case
  * Build xauth before running tests.
  * autogen: add default patch prefix
  * autogen.sh: stop using maintainer mode
  * autogen.sh: use exec instead of waiting for configure to finish
  * usage(): Print summary for the -n option
* Wed May  7 2014 sndirsch@suse.com
- Update to version 1.0.9
  * Add AC_USE_SYSTEM_EXTENSIONS to expose non-standard extensions
  * Do not install test_xauth during "make install" as it is
  * Fix warning about warn_unused_result triggered by WRITES.
  * Fixed missing EXTRA_DIST in tests. Extended README for releasing.
* Fri Oct 25 2013 sndirsch@suse.com
- Update to version 1.0.8
  * Fix a long standing problem that for ssh tunneled connections a
    display variable of the form: localhost:<N>.<M> leads to correct
    authorization when an X client is started but "xauth list $DISPLAY"
    returns nothing.
  * Fix for: If using GDM with XDMCP, then ssh is not able to start X11
    clients on the remote side. You get a "No xauth data; using fake
    authentication data for X11 forwarding." from SSH.
- obsoletes xauth-1.0.2.diff,
  u_xauth_Look-for-FamilyLocal-if-inet-or-inet6-addr.patch
- adjusted xauth-tolerant-hostname-changes.diff
- added new test_xauth tool to %%files section
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.0.7:
  + Remove alarm handler in get_hostname
  + Add const attributes to fix gcc -Wwrite-strings warnings
  + convert strlen/malloc/strcpy combo to strdup
- Changes from version 1.0.6:
  + auth_finalize: Attempt to rename() if link() fails
  + Error out and avoid a call to malloc(0) if given a bad hex
    string
  + Build system fixes.
- Rebase xauth-tolerant-hostname-changes.diff.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xauth from xorg-x11. Initial version: 1.0.5.
